require 'gizmos_simple_merchant.item_value_functions'
require 'gizmos_simple_merchant.item_value_definitions'
--=====================================================================
--					OBJVAR FORMAT INFORMATION
--=====================================================================
-----------------------------------------------------------------------
--						 current_stock_list
-----------------------------------------------------------------------
--<template> : <display name> : <sell price> : <current_stock_count> : <max_stock_count> : <stackable>
--"loa_dagger_dagger:Dagger:125c:4:10:false"

-----------------------------------------------------------------------
--						  stock_data_list
-----------------------------------------------------------------------
--<template> : <display name> : <sell price> : <max_stock_count> : <stackable>
--"loa_dagger_dagger:Dagger:125c:10:false"

-----------------------------------------------------------------------
--						  	 buy_list
-----------------------------------------------------------------------
--<template> : <dispal name> : <buy price> : <stackable>
--"loa_dagger_dagger:Dagger:125c:false"


--=====================================================================
--						GLOBAL VARIABLES
--=====================================================================
-----------------------------------------------------------------------
--		Variable for Passing the Admin Through Functions
-----------------------------------------------------------------------
--I should be able to pass objects through the targeting
--system but instead im stuck doing this stupid shit and
--adding a global UserForTargeting value to pass....bleh
local UserForTargeting = nil

--if you want to use this script to control your directory name
--then toggle this to variable to true and enter a valid
--directory name in SaveDirectoryLocation
local I_KNOW_MY_DIRECTORY_INFO = false

--if you are using this script to control your directory name
--and location, enter the valid name of the direcotry here and
--toggle the I_KNOW_MY_DIRECTORY_INFO to true
local SaveDirectoryLocation = ""

--for acting like the player to the dialog system to test as if
--you where a player..can only be accessed by this script.
local ActLikePlayer = false
--=====================================================================
--							CORE FUNCTIONS
--=====================================================================
-----------------------------------------------------------------------
--						GetAttention(user)					  
-----------------------------------------------------------------------
--this is called to make the merchant face the player when clicked
--or used.
function GetAttention(user)
    this:StopMoving()
    this:SetFacing(this:GetLoc():YAngleTo(user:GetLoc()))
end

-----------------------------------------------------------------------
--				HandleItemEquipped(success, objref, hue)
-----------------------------------------------------------------------
--this is called by so that we can hue the merchants clothing 
function HandleItemEquipped(success, objref, hue)
	objref:SetHue(hue)
end

-----------------------------------------------------------------------
--					    HandleModuleAttached()	  
-----------------------------------------------------------------------
--this just sets up some common variables needed that I felt I really
--did not need to include with the .xml file of the merchants
function HandleModuleAttached()
	this:SetObjVar("current_stock_list",{})
	this:SetObjVar("stock_data_list",{})
	this:SetObjVar("buy_list",{})

	local delay = this:GetObjVar("restock_delay")
	this:ScheduleTimerDelay(TimeSpan.FromSeconds(delay), "restockTimer")
	AddUseCase(this,"Buy",false)
	AddUseCase(this,"Sell",false)
	AddUseCase(this,"Talk",true)
end

-----------------------------------------------------------------------
--					    DestroyInSlot(slot)	  
-----------------------------------------------------------------------
--used in the vendor initialization
function DestroyInSlot(slot)
	local currentEquipped = this:GetEquippedObject(slot)
	if (currentEquipped ~= nil) then
		currentEquipped:Destroy()
	end
end

-----------------------------------------------------------------------
--				 UpdateInventoryItem(index,amount)		  
-----------------------------------------------------------------------
--when the vendors inventory needs to remove a item this function will
--clean it off the current_stock_list objvar
function UpdateInventoryItem(index,amount)
	local current_stock_list = this:GetObjVar("current_stock_list")
	local sellData = StringSplit(current_stock_list[tonumber(index)],":")
	local currentCount = tonumber(sellData[4])
	currentCount = currentCount - amount
	local repack = sellData[1]..":"..sellData[2]..":"..sellData[3]..":"..currentCount..":"..sellData[5]..":"..sellData[6]
	table.remove(current_stock_list,index)
	table.insert(current_stock_list,index,repack)
	this:SetObjVar("current_stock_list",current_stock_list)
end

-----------------------------------------------------------------------
--			HandleConsumeResource(user,resourceType,amount)		  
-----------------------------------------------------------------------
--this is used to handle the money transactions in the buy menu for the
--players.
function HandleConsumeResource(user,resourceType,amount)
	local success = false

	local backpackObj = user:GetEquippedObject("Backpack")
	if( backpackObj ~= nil and CountResourcesInContainer(backpackObj,resourceType) >= amount ) then
		local resourceObjs = GetResourcesInContainer(backpackObj,resourceType)
		-- sort stackable objects from smallest to largest
		table.sort(resourceObjs,function(a,b) return GetStackCount(a)<GetStackCount(b) end)
		local remainingAmount = amount
		for index, resourceObj in pairs(resourceObjs) do
			local resourceCount = GetStackCount(resourceObj)
			if( resourceCount > remainingAmount ) then				
				RequestSetStackCount(resourceObj,resourceCount - remainingAmount)
				remainingAmount = 0
			else
				remainingAmount = remainingAmount - resourceCount
				resourceObj:Destroy()
			end

			if( remainingAmount == 0 ) then
				break
			end
		end

		success = true
	end
	return success
end

-----------------------------------------------------------------------
--					GeneratePurchasableItemsForAdmin(user)	  
-----------------------------------------------------------------------
--this function works with CheckisOnBuyList function to gather a list of
--items this merchant will buy from the player.
function GeneratePurchasableItemsForAdmin(user)
	local buyList = this:GetObjVar("buy_list")
	local purchaseableList = {}
	for i, itemList in pairs(buyList) do
		local data = StringSplit(itemList,":")
		local template = data[1]
		local displayName = data[2]
		local price = data[3]
		local stackable = data[4]

		local listItem = displayName .. ":" ..tostring(GetTemplateIconId(template)) .. ":" .. price .. ":" .. stackable .. ":" .. template
		table.insert(purchaseableList,listItem)
	end
	return purchaseableList
end

-----------------------------------------------------------------------
--					GeneratePurchasableItemsFromPlayer(user)	  
-----------------------------------------------------------------------
--this function works with CheckisOnBuyList function to gather a list of
--items this merchant will buy from the player.
function GeneratePurchasableItemsFromPlayer(user)
	local backpackObj = user:GetEquippedObject("Backpack")
	local buyList = this:GetObjVar("buy_list")
	local purchaseList = {}
    local pouchItem = FindItemInContainerRecursive(backpackObj,
        function(item)            
        	CheckIsOnBuyList(item,purchaseList)
        end)
    return purchaseList
end

-----------------------------------------------------------------------
--					CheckIsOnBuyList(item,list)		  
-----------------------------------------------------------------------
--this function works with GeneratePurchasableItemsFromPlayer function 
--to gather a list of items this merchant will buy from the player.
function CheckIsOnBuyList(item,list)
	local buyList = this:GetObjVar('buy_list')
	for buyListIndex, buyListItem in pairs(buyList) do
		local parseItem = StringSplit(buyListItem,":")
		if(parseItem[1] == item:GetCreationTemplateId()) then
			local listItem = parseItem[2] .. ":" ..item.Id .. ":" .. parseItem[3] .. ":" .. parseItem[1]
			table.insert(list,listItem)
		end
	end
end

-----------------------------------------------------------------------
--					CheckIsObjectStackable(target)  
-----------------------------------------------------------------------
--well is it?
function CheckIsObjectStackable(target)
	return target:HasModule("stackable") or target:HasModule("coins")
end

-----------------------------------------------------------------------
--					StripColorFromString(inputStr)	  
-----------------------------------------------------------------------
--this function is already created but I put it in this file so it can
--be a stand alone in case CS decides to mess it up
function StripColorFromString(inputStr)
  	local color = string.match(inputStr,"%[......%]")
  	local outStr = string.gsub(inputStr,"%[......%]","")
  	local outStr = string.gsub(outStr,"%[%-%]","")
  	return outStr, color
end

-----------------------------------------------------------------------
--						GetObjectStackCount(target)  
-----------------------------------------------------------------------
--how many items are in that stack of them ingots?
function GetObjectStackCount(target)
	if( IsStackable(target) ) then
		return target:GetObjVar("StackCount") or 1
	else
		return 1
	end 
end

function GetMoneyString(coin_total)
	local temp = coin_total:gsub("c","")
	local coins = tonumber(temp)

	local plat = 0
	local gold = 0
	local silver = 0
	local copper = 0
	if(coins > 999999) then --platinum
		while (coins > 999999) do
			plat = plat + 1
			coins = coins - 1000000
		end
	end
	if(coins > 9999) then --gold
		while (coins > 9999) do
			gold = gold + 1
			coins = coins - 10000
		end
	end
	if(coins > 99) then --silver
		while (coins > 99) do
			silver = silver + 1
			coins = coins - 100
		end
	end
	local returnString = ""
	if(plat > 0) then returnString = returnString .. plat .. "[BBBBBB]p[FFFFFF]" end
	if(gold > 0) then returnString = returnString .. gold .. "[BBBB00]g[FFFFFF]" end
	if(silver > 0) then returnString = returnString .. silver .. "[939393]s[FFFFFF]" end
	if(coins > 0) then returnString = returnString .. coins .. "[FF7700]c[FFFFFF]" end
	return returnString
end


--======================================================================
--							EVENT HANDLERS
--======================================================================
----------------------------------------------------------
--EVENTTYPE - ContainerItemAdded
----------------------------------------------------------
--used for when you try to dress the merchant
RegisterEventHandler(EventType.ContainerItemAdded, "", 
    function(addedObj)
    	if(this:GetObjVar("mode")=="Dress Mode") then
	    	local template = addedObj:GetCreationTemplateId()
	    	local hue = addedObj:GetHue()
		   	if (addedObj:GetSharedObjectProperty("EquipSlot") == "Chest") then
		        DestroyInSlot("Chest")
		        CreateEquippedObj(template, this, "itemEquipped", hue)
		    end
		   	if (addedObj:GetSharedObjectProperty("EquipSlot") == "Legs") then
		        DestroyInSlot("Legs")
		        CreateEquippedObj(template, this, "itemEquipped", hue)
		    end
		   	if (addedObj:GetSharedObjectProperty("EquipSlot") == "Head") then
		        DestroyInSlot("Head")
		        CreateEquippedObj(template, this, "itemEquipped", hue)
		    end					
		   	if (addedObj:GetSharedObjectProperty("EquipSlot") == "RightHand") then
		        DestroyInSlot("RightHand")
		        CreateEquippedObj(template, this, "itemEquipped", hue)
		    end
		   	if (addedObj:GetSharedObjectProperty("EquipSlot") == "LeftHand") then
		        DestroyInSlot("LeftHand")
		        CreateEquippedObj(template, this, "itemEquipped", hue)
		    end
		else
			addedObj:Destroy()
		end
    end)

----------------------------------------------------------
--EVENTTYPE - EventType.Message
----------------------------------------------------------
--setup the buy/sell options on the merchant
RegisterEventHandler(EventType.Message, "UseObject", 
	function(user,usedType)
		if(usedType=="Buy") then
			GetAttention(user)
			MerchantBuyWindow(user)
		end
		if(usedType=="Sell") then
			GetAttention(user)
			MerchantSellWindow(user)
		end
		if(usedType=="Talk") then
			GetAttention(user)
			IntroductionWindow(user)
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.CreatedObject
----------------------------------------------------------
--vendor dress system
RegisterEventHandler(EventType.CreatedObject, "itemEquipped", HandleItemEquipped)

----------------------------------------------------------
--EVENTTYPE - EventType.ModuleAttached
----------------------------------------------------------
--no need for explanation here
RegisterSingleEventHandler(EventType.ModuleAttached, GetCurrentModule(), HandleModuleAttached)

----------------------------------------------------------
--EVENTTYPE - EventType.LoadedFromBackup
----------------------------------------------------------
--since the merchant just got reloaded into the world
--lets get the restock timer back up and running
RegisterEventHandler(EventType.LoadedFromBackup,"",
	function ()
		local delay = this:GetObjVar("restock_delay")
		this:ScheduleTimerDelay(TimeSpan.FromSeconds(delay), "restockTimer")
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse
----------------------------------------------------------
--this handles all the merchants buy window responses
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantBuyWindow", 
	function (user,buttonId,textField)
		local buttonData = StringSplit(buttonId,":")
		local button = buttonData[1]
		local index = buttonData[2]

		if(button == "sellItemToPlayer") then
			local current_stock_list = this:GetObjVar("current_stock_list")
			local sellData = StringSplit(current_stock_list[tonumber(index)],":")
			local cost = sellData[3]:gsub("c","")

			local finalcost = item_value_buy_price(user,this,tonumber(cost))

			--if not stackable process normally
			if(sellData[6]=="false") then
				if(HandleConsumeResource(user,"coins",tonumber(finalcost))) then
					local backpackObj = user:GetEquippedObject("Backpack")
					CreateObjInContainer(sellData[1], backpackObj, GetRandomDropPosition(backpackObj), "soldItemToPlayer", 1)
					UpdateInventoryItem(index,1)
					user:SystemMessage("you purchased a [FF7700]" ..sellData[2].. "[FFFFFF] for ("..GetMoneyString(sellData[3]).."[FFFFFF]) from "..this:GetName())
					MerchantBuyWindow(user)
				else
					user:SystemMessage("you do not have the funds for this")
				end
			else
				BuyQuantityWindow(user,index)
			end	
		end
		if(button == "deleteItem") then
			local currentStockList = this:GetObjVar("current_stock_list")
			local stockDataList = this:GetObjVar("stock_data_list")
			local tableToDelete = currentStockList[tonumber(index)]
			local stockDeleteIndex = 0

			local currentStockData = StringSplit(tableToDelete,":")

			for stockIndex, stockTable in pairs(stockDataList) do
				local stockData = StringSplit(stockTable,":")
				if(stockData[1] == currentStockData[1] and stockData[2] == currentStockData[2]) then
					stockDeleteIndex = stockIndex
				end
			end
			user:SystemMessage("you have deleted the stock item [FF7700]"..currentStockData[1].."[FFFFFF] from "..this:GetName().."[FFFFFF] inventory.")
			table.remove(currentStockList,tonumber(index))
			table.remove(stockDataList,stockDeleteIndex)

			this:SetObjVar("current_stock_list",currentStockList)
			this:SetObjVar("stock_data_list",stockDataList)
			MerchantBuyWindow(user)
		end
		if(button == "addStock") then
			--AddStockWindow(user)
			--what a stupid fix
			UserForTargeting = user
			user:RequestClientTargetGameObj(this, "targetedStockItem")
			user:SystemMessage("target a item you wish to add to the vendors stock list")
		end
		if(IsGod(user) and button=="close_button") then
			this:SetObjVar("mode","Vendor Mode")
		end
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse
----------------------------------------------------------
--this handles all the merchants buy window responses
RegisterEventHandler(EventType.DynamicWindowResponse,"IntroductionWindow", 
	function (user,buttonId)
		if(buttonId == "buy_button") then
			MerchantBuyWindow(user)
		end
		if(buttonId == "sell_button") then
			MerchantSellWindow(user)
		end
		if(buttonId == "repair_button") then
			UserForTargeting = user
			user:RequestClientTargetGameObj(this, "targetedRepairItem")
			user:SystemMessage("target a item you wish to have the vendor repair...")			
		end
		if(buttonId == "change_name_text_button") then
			EditNameWindow(user)
		end
		if(buttonId == "change_title_text_button") then
			EditTitleWindow(user)
		end
		if(buttonId == "change_buy_text_button") then
			EditBuyTextWindow(user)
		end
		if(buttonId == "change_sell_text_button") then
			EditSellTextWindow(user)
		end
		if(buttonId == "change_repair_text_button") then
			EditRepairTextWindow(user)
		end
		if(buttonId == "change_dialog_text_button") then
			EditDialogTextWindow(user,false)
		end
		if(buttonId == "createme_button") then
			if(user:GetObjVar("ModName") ~= nil) then
				local file = io.open("mods/".. user:GetObjVar("ModName") .."/templates/merchants/test_item.xml","w")
				if(file ~= nil) then
					local directory = "mods/".. user:GetObjVar("ModName") .."/templates/merchants/"
					local name, color = StripColorFromString(this:GetName())
					local name = name:lower()
					local filename = string.gsub(name," ","_")
					local fullpath = directory .. filename .. ".xml"
					ExportToXml(fullpath,user)
				else
					user:SystemMessage("[FF7700]-------------------------------------------------")
					user:SystemMessage("[22FF22]                  -[SETUP REQUIRED]-")
					user:SystemMessage("[FF7700]-------------------------------------------------")
					user:SystemMessage("[22FF22]Simply Do The Following")
					user:SystemMessage("[FFFFBB]I see you completed step 1 by creating your ModName variable. One more step and we will be ready. Create a folder named [FF7700]'merchants' [FFFFBB] in your mods/"..user:GetObjVar("ModName").."/templates directory")
				end
			else
				user:SystemMessage("[FF7700]-------------------------------------------------")
				user:SystemMessage("[22FF22]                  -[SETUP REQUIRED]-")
				user:SystemMessage("[FF7700]-------------------------------------------------")
				user:SystemMessage("[22FF22]Simply Do The Following")
				user:SystemMessage("[FFFFBB]Add a string variable named [FF7700]'ModName'[FFFFBB] to your character. Name this variable the same name as your mod name, remember folders are case sensitive. This is so you can save these templates directly to your mod folder. These templates will be placed in the following directory [FF7700]'yourmod/templates/merchants'")
			end
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Vendor Mode")
		end							
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--for when the admin changes the buy text dialog label
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantEditBuyTextWindow", 
	function (user,buttonId,textField)
		if(buttonId=="changeBuyText") then
			this:SetObjVar("BuyText",textField.edit_buy_field)
			IntroductionWindow(user)
			user:SystemMessage("you changed this merchants buy text label")
		end
		if(buttonId=="cancel" or buttonId=="") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to change the merchants buy text label")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end							
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--for when the admin changes the buy text dialog label
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantEditSellTextWindow", 
	function (user,buttonId,textField)
		if(buttonId=="changeSellText") then
			this:SetObjVar("SellText",textField.edit_sell_field)
			IntroductionWindow(user)
			user:SystemMessage("you changed this merchants sell text label")
		end
		if(buttonId=="cancel" or buttonId=="") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to change the merchants sell text label")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--for when the admin changes the buy text dialog label
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantEditRepairTextWindow", 
	function (user,buttonId,textField)
		if(buttonId=="changeRepairText") then
			this:SetObjVar("RepairText",textField.edit_repair_field)
			IntroductionWindow(user)
			user:SystemMessage("you changed this merchants repair text label")
		end
		if(buttonId=="cancel" or buttonId=="") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to change the merchants repair text label")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--for when the admin changes the buy text dialog label
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantEditDialogTextWindow", 
	function (user,buttonId,textField)
		if(buttonId=="changeDialogText") then
			this:SetObjVar("DialogText",textField.edit_dialog_field)
			IntroductionWindow(user)
			user:SystemMessage("you changed this merchants dialog text label")
		end
		if(buttonId=="cancel" or buttonId=="") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to change the merchants dialog text label")
		end
		if(buttonId == "clearDialogText") then
			EditDialogTextWindow(user,true)
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.ClientTargetGameObjResponse
----------------------------------------------------------
--called when the admin wants to target a item to add to the
--merchants list of items to sell
RegisterEventHandler(EventType.ClientTargetGameObjResponse, "targetedStockItem", 
    function(target)
    		AddStockWindow(target)
        end)

----------------------------------------------------------
--EVENTTYPE - EventType.ClientTargetGameObjResponse
----------------------------------------------------------
--called for item repairing
RegisterEventHandler(EventType.ClientTargetGameObjResponse, "targetedRepairItem", 
    function(target)
		--repair code here
		local cost = repair_cost(UserForTargeting, this, target, 5)
		if(target:GetObjVar("Durability") ~= nil) then
    		local totalDurabilityLoss = target:GetObjVar("MaxDurability") - target:GetObjVar("Durability")
    		if(totalDurabilityLoss < 1) then
    			UserForTargeting:SystemMessage("this item is already fully repaired")
    		else
    			cost = cost * totalDurabilityLoss
    			RepairWindow(UserForTargeting,cost, target.Id)
    			UserForTargeting:SystemMessage("this item will cost you " .. GetMoneyString(tostring(cost)) .. " to repair")
    		end
		else
			UserForTargeting:SystemMessage("this item does not need repaired...")
			IntroductionWindow(UserForTargeting)
		end
    end)

----------------------------------------------------------
--EVENTTYPE - EventType.Timer
----------------------------------------------------------
--when the timer is up..... restock fool...
RegisterEventHandler(EventType.Timer, "restockTimer", 
	function()
		local delay = this:GetObjVar("restock_delay")
		this:ScheduleTimerDelay(TimeSpan.FromSeconds(delay), "restockTimer")
		this:SetObjVar("current_stock_list",this:GetObjVar("stock_data_list"))
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.CreatedObject
----------------------------------------------------------
--if you sell an item to the merchant, it will fix the 
--quantity of it. this is also called when the merchant
--gives the player some coins
RegisterEventHandler(EventType.CreatedObject, "soldItemToPlayer", 
	function(success, objref,quantity)
		if(type(quantity) == "number") then
			if(success and quantity > 1) then
				RequestSetStack(objref,quantity)
			end
		else
			SetItemTooltip(objref)			
		end
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--for when the player changes the merchant name
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantRepairWindow", 
	function (user,buttonId)
		local buttonData = StringSplit(buttonId,":")
		local button = buttonData[1]
		local cost = buttonData[2]
		local repairItemId = buttonData[3]

		if(button=="repairItem" and repairItemId ~= nil) then
			if(HandleConsumeResource(user,"coins",tonumber(cost))) then
				local repairItem = GameObj(tonumber(repairItemId))
				local maxDurability = repairItem:GetObjVar("MaxDurability")
				
				maxDurability = maxDurability - math.random(1,3)
				if(maxDurability < 1) then
					user:SystemMessage("you paid ("..GetMoneyString(cost).."[FFFFFF]) but your item [AA0000]broke")
					repairItem:Destroy()
				else
					user:SystemMessage("you paid ("..GetMoneyString(cost).."[FFFFFF]) your item [22AA22]repaired")
					repairItem:SetObjVar("MaxDurability",maxDurability)
					repairItem:SetObjVar("MinDurability",maxDurability)
				end
				IntroductionWindow(user)
			else
				user:SystemMessage("you do not have the repair cost amount...")
			end
		end
		if(button=="cancel" or button=="close_window") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to repair your item")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)



----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--for when the player accepts the repair cost
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantEditNameWindow", 
	function (user,buttonId,textField)
		if(buttonId=="changeName") then
			this:SetName(textField.edit_name_field)
			this:SetSharedObjectProperty("DisplayName",textField.edit_name_field)
			IntroductionWindow(user)
			user:SystemMessage("you changed this merchants name")
		end
		if(buttonId=="cancel" or buttonId=="") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to change the merchants name")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--this controls the responses for when the player is picking things
--they want to sell from their backpack to the merchant
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantSellWindow", 
	function (user,buttonId,textField)
		local parseItem = StringSplit(buttonId,":")
		local button = parseItem[1]
		local param = parseItem[2]
		local arg = parseItem[3]
		if(button == "deleteItem") then
			local buyList = this:GetObjVar("buy_list")
			local tableToDelete = buyList[tonumber(param)]
			local tableData = StringSplit(tableToDelete,":")

			user:SystemMessage("you have deleted the stock item [FF7700]"..tableData[2].."[FFFFFF] from "..this:GetName().."[FFFFFF] buy list.")
			table.remove(buyList,tonumber(param))



			this:SetObjVar("buy_list",buyList)
			MerchantSellWindow(user)			
		end

		if (button == "addPurchaseItem") then
			--what a stupid fix
			UserForTargeting = user
			user:RequestClientTargetGameObj(this, "targetedPurchaseItem")
			user:SystemMessage("target a item you want to merchant to buy off players")
		end

		if(button == "sellItem") then			
			local objectToSell = GameObj(tonumber(param))
			local price = arg:gsub("c","")
			local backpackObj = user:GetEquippedObject("Backpack")
			if(CheckIsObjectStackable(objectToSell)) then
				--goto item_value_function.lua to script your own changes
				--in the price of the item.
				price = item_value_sell_price(user,this,tonumber(price))
				SellQuantityWindow(user,buttonId)
			else
				objectToSell:Destroy()
				CreateObjInContainer("coin_purse", backpackObj, GetRandomDropPosition(backpackObj), "soldItemToPlayer", tonumber(price))
				--CreateObjInBackpackOrAtLocation(user,"coin_purse", "soldItemToPlayer", tonumber(price))
				CallFunctionDelayed(TimeSpan.FromSeconds(1),function()MerchantSellWindow(user)end)			
			end
		end
		if(IsGod(user) and button=="close_button") then
			this:SetObjVar("mode","Vendor Mode")
		end
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.ClientTargetGameObjResponse
----------------------------------------------------------
--when the admin wants to add a item the vendor can buy
--from a player
RegisterEventHandler(EventType.ClientTargetGameObjResponse, "targetedPurchaseItem", 
    function(target)
    		AddToBuyList(target)
        end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse 
----------------------------------------------------------
--when the admin responds to the sell list window so they can add
--a item to the list
RegisterEventHandler(EventType.DynamicWindowResponse,"AddToBuyListkWindow", 
	function (user,buttonId,textField)
		if(buttonId=="addBuyListItem") then
			local template = textField.text_field_template
			local displayName = textField.text_field_display_name
			local price = textField.text_field_price.."c"
			local currentStock = textField.text_field_max_stock
			local stackable = textField.text_field_stackable
			--local icon = textField.text_field_icon
			local stockData = template .. ":" .. displayName .. ":" .. price .. ":" .. stackable

			local buy_list = this:GetObjVar("buy_list")
			table.insert(buy_list,stockData)

			this:SetObjVar("buy_list",buy_list)

			user:SystemMessage("you have added [FF7700] "..displayName.." [FFFFFF]to the merchant "..this:GetName().. " [FFFFFF] buy list.")

			MerchantSellWindow(user)
		end
		if(buttonId=="cancel" or buttonId=="") then
			MerchantSellWindow(user)
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse
----------------------------------------------------------
--for when you edit the title of the merchant
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantEditTitleWindow", 
	function (user,buttonId,textField)
		if(buttonId=="changeTitle") then
			this:SetSharedObjectProperty("Title", textField.edit_title_field .. "[-]")
			IntroductionWindow(user)
			user:SystemMessage("you changed the title of the merchant")
		end
		if(buttonId=="cancel" or buttonId=="") then
			IntroductionWindow(user)
			user:SystemMessage("you decided not to change the title of the vendor")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse
----------------------------------------------------------
--when you fill out the add stock window and decide to add it
--to the merchant
RegisterEventHandler(EventType.DynamicWindowResponse,"AddToStockWindow", 
	function (user,buttonId,textField)
		if(buttonId=="addStockItem") then
			local template = textField.text_field_template
			local displayName = textField.text_field_display_name
			local cost = textField.text_field_cost.."c"
			local currentStock = textField.text_field_max_stock
			local maxStock = textField.text_field_max_stock
			local stackable = textField.text_field_stackable
			
			local stockData = template .. ":" .. displayName .. ":" .. cost .. ":" .. currentStock .. ":" .. maxStock .. ":" .. stackable

			local stock_data_list = this:GetObjVar("stock_data_list")
			table.insert(stock_data_list,stockData)
			this:SetObjVar("current_stock_list",stock_data_list)
			this:SetObjVar("stock_data_list",stock_data_list)

			user:SystemMessage("you have added [FF7700]"..maxStock.." "..displayName.." [FFFFFF]to the merchant "..this:GetName())

			MerchantBuyWindow(user)
		end
		if(buttonId=="cancel" or buttonId=="") then
			MerchantBuyWindow(user)
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse
----------------------------------------------------------
--when you want to buy a quanity from the merchant
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantBuyQuantityWindow", 
	function (user,buttonId,textField)
		local parseItem = StringSplit(buttonId,":")
		local button = parseItem[1]
		local index = parseItem[2]
		if(button=="buyQuantity") then

			local current_stock_list = this:GetObjVar("current_stock_list")
			local sellData = StringSplit(current_stock_list[tonumber(index)],":")
			local cost = sellData[3]:gsub("c","")
			local currentCount = sellData[4]		
			local quantity_to_buy = textField.quantity_to_buy

			if(tonumber(quantity_to_buy) > tonumber(currentCount)) then quantity_to_buy = tonumber(currentCount) end

			local finalcost = tonumber(cost) * tonumber(quantity_to_buy)
			finalcost = item_value_buy_price(user,this,finalcost)


			if(HandleConsumeResource(user,"coins",finalcost)) then
				local backpackObj = user:GetEquippedObject("Backpack")
				CreateObjInContainer(sellData[1], backpackObj, GetRandomDropPosition(backpackObj), "soldItemToPlayer", tonumber(quantity_to_buy))
				UpdateInventoryItem(index,quantity_to_buy)
				user:SystemMessage("you purchased [FF7700]"..quantity_to_buy.. " [FF7700]" ..sellData[2].."'s[FFFFFF]("..GetMoneyString(finalcost.."c").."[FFFFFF]) from "..this:GetName())
				MerchantBuyWindow(user)
			else
				user:SystemMessage("you do not have the funds for this")
			end			
			MerchantBuyWindow(user)
		end
		if(button=="cancel" or buttonId=="") then
			MerchantBuyWindow(user)
			user:SystemMessage("you decided not to purchase anything")
		end
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end		
	end)

----------------------------------------------------------
--EVENTTYPE - EventType.DynamicWindowResponse
----------------------------------------------------------
--when you want to sell a quanity of an item to a merchant
RegisterEventHandler(EventType.DynamicWindowResponse,"MerchantSellQuantityWindow", 
	function (user,buttonId,textField)
		local parseItem = StringSplit(buttonId,":")
		local button = parseItem[1]
		-- parseItem[2] is dead data from a previous function no need to cut it out
		local objId = parseItem[3]
		local price = parseItem[4]:gsub("c","")
		local finalprice = tonumber(price)
		finalprice = item_value_sell_price(user,this,finalprice)

		if(button == "sellQuantity") then
			local object = GameObj(tonumber(objId))
			local quanitityToSell = tonumber(textField.quantity_to_sell)
			local objectStackSize = GetObjectStackCount(object)
			local backpackObj = user:GetEquippedObject("Backpack")
			if(quanitityToSell >= objectStackSize) then
				CreateObjInContainer("coin_purse", backpackObj, GetRandomDropPosition(backpackObj), "soldItemToPlayer", (finalprice * objectStackSize))
				object:Destroy()
				user:SystemMessage(this:GetName().."[FFFFFF] has paid you ".. GetMoneyString(""..(finalprice * quanitityToSell).."c") .. "[FFFFFF] for [BBBB00]" .. objectStackSize .. " [FFFFFF]items")
			else
				CreateObjInContainer("coin_purse", backpackObj, GetRandomDropPosition(backpackObj), "soldItemToPlayer", (finalprice * quanitityToSell))
				RequestSetStackCount(object,objectStackSize - quanitityToSell)
				user:SystemMessage(this:GetName().."[FFFFFF] has paid you ".. GetMoneyString(""..(finalprice * quanitityToSell).."c") .. "[FFFFFF] for [BBBB00]" .. quanitityToSell .. " [FFFFFF]items")
			end
		end
		if(button == "cancel") then
			MerchantSellWindow(user)
			user:SystemMessage("you decide not to sell the quantity of items")
		end
		CallFunctionDelayed(TimeSpan.FromSeconds(1),function()MerchantSellWindow(user)end)
		if(IsGod(user)) then
			this:SetObjVar("mode","Dress Mode")
		end			
	end)

--======================================================================
--					  EXPORT DATA TO FILE FUNCTIONS
--======================================================================
----------------------------------------------------------
--			      ExportToXml(fullpath,user)
----------------------------------------------------------
--this will save the merchant information to a template file
--in order for this feature to work. you must have 2 things
--setup. this system will tell you in game if you try to click
--the Create XML button. Here is what is needed
--1) you need to have a ObjVar string on your admin player named
--   ModName.then set the value to the name of the mod folder you
--   want to have the files saved too. remember its case sensitive.
--2) you need a folder named merchants in your modname/templates
--   directory.
--
--if all this is setup correctly you will get a confirmation message
--in the chat box when you use the Create XML button. Enjoy


--probably a dozen better ways of saving this stuff but I did it this way
--because i was to lazy to look up a package for xml and I don't like the
--one CS provides.

function ExportToXml(fullpath,user)
	print("--------------------------------------------------------------------------")
	print("     Exporting a merchant file created by Gizmos Simple Vendor System     ")
	print("--------------------------------------------------------------------------")
	if(I_KNOW_MY_DIRECTORY_INFO) then
		fullpath = SaveDirectoryLocation
	end
	local file = io.open(fullpath,"w")
	local body_type = 1
	local use_icons = "True"
	if not(IsMale(this)) then body_type = 208 end
	if not(this:GetObjVar("use_icons")) then use_icons = "False" end
	print("Writing file -> "..fullpath)
	print("Writing Merchant Configurations...")
	file:write("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n")
	file:write("<ObjectTemplate xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\">\n")
	file:write("\t<ClientId>" .. body_type .. "</ClientId>\n")
	file:write("\t<Hue>0xFFFFFFFF</Hue>\n")
	file:write("\t<Name>" .. this:GetName() .. "</Name>\n")
	file:write("\t<SharedStateEntry name=\"Title\" type=\"string\" value=\"" .. this:GetSharedObjectProperty("Title") .. "\"/>\n")
	file:write("\t<ObjectVariableComponent>\n")
	file:write("\t\t<StringVariable Name=\"MobileTeamType\">Villagers</StringVariable>\n")
	file:write("\t\t<DoubleVariable Name=\"BaseHealth\">300</DoubleVariable>\n")
	file:write("\t\t<BoolVariable Name=\"ImportantNPC\">True</BoolVariable>\n")
	file:write("\t\t<BoolVariable Name=\"initialized\">True</BoolVariable>\n")
	file:write("\t\t<BoolVariable Name=\"noloot\">True</BoolVariable>\n")
	if(this:GetObjVar("CanDoRepairs")) then
		file:write("\t\t<BoolVariable Name=\"CanDoRepairs\">True</BoolVariable>\n")
	else
		file:write("\t\t<BoolVariable Name=\"CanDoRepairs\">False</BoolVariable>\n")
	end
	file:write("\t\t<BoolVariable Name=\"use_icons\">" .. use_icons .. "</BoolVariable>\n")
	file:write("\t\t<DoubleVariable Name=\"restock_delay\">" .. this:GetObjVar("restock_delay") .. "</DoubleVariable>\n")
	file:write("\t\t<StringVariable Name=\"mode\">Vendor Mode</StringVariable>\n")
	file:write("\t</ObjectVariableComponent>\n")
	file:write("\t<ScriptEngineComponent>\n")
	file:write("\t\t<LuaModule Name=\"gizmos_simple_merchant.gizmos_simple_merchant\"/>\n")
	file:write("\t\t<LuaModule Name=\"gizmos_simple_merchant.gizmos_simple_merchant_initializer\">\n")
	file:write("\t\t\t<Initializer>\n")
	file:write("\t\t\t{\n")
	print("Writing Dialog Information....")
	WriteDialogs(file)
	print("Writing Equipped Items...")
	WriteEquippedItems(file)
	print("Writing Core Inventory....")
	WriteCoreInventory(file)
	print("Writing Buy List....")
	WriteBuyList(file)
	file:write("\t\t\t}\n")
	file:write("\t\t\t</Initializer>\n")
	file:write("\t\t</LuaModule>\n")
	file:write("\t</ScriptEngineComponent>\n")
	file:write("\t<MobileComponent>\n")
	file:write("\t\t<BaseRunSpeed>1</BaseRunSpeed>\n")
	file:write("\t\t<MobileType>Friendly</MobileType>\n")
	file:write("\t</MobileComponent>\n")
	file:write("</ObjectTemplate>")
	file:close()
	print("--------------------------------------------------------------------------")
	print("     Template Completed, thank you for using Gizmos Simple Merchants      ")
	print("--------------------------------------------------------------------------")
	user:SystemMessage("[FF7700]"..fullpath.."[FFFFBB]... scripted and saved!")
end

----------------------------------------------------------
--			  WriteDialogs(file)
----------------------------------------------------------
--this formats the merchants equipment to the xml file
function WriteDialogs(file)
	file:write("\t\t\t\tDialogText =\"".. this:GetObjVar("DialogText") .. "\",\n")
	file:write("\t\t\t\tBuyText =\"".. this:GetObjVar("BuyText") .. "\",\n")
	file:write("\t\t\t\tSellText =\"".. this:GetObjVar("SellText") .. "\",\n")
	file:write("\t\t\t\tRepairText =\"".. this:GetObjVar("RepairText") .. "\",\n")
end

----------------------------------------------------------
--			  WriteEquippedItems(file)
----------------------------------------------------------
--this formats the merchants equipment to the xml file
function WriteEquippedItems(file)
	file:write("\t\t\t\tEquipment =\n")
	file:write("\t\t\t\t{\n")
	for i,equipObj in pairs(this:GetAllEquippedObjects()) do	
		file:write("\t\t\t\t\t{\""..equipObj:GetCreationTemplateId().."\",\"".. equipObj:GetHue() .. "\"},\n")
	end
	file:write("\t\t\t\t},\n")
end

----------------------------------------------------------
--				WriteCoreInventory(file)
----------------------------------------------------------
--this formats the inventory the merchant sells to the
--xml file
function WriteCoreInventory(file)
	file:write("\t\t\t\tInventory =\n")
	file:write("\t\t\t\t{\n")
	for i,iventoryItem in pairs(this:GetObjVar("stock_data_list")) do
		local inventoryItemData = StringSplit(iventoryItem,":")
		file:write("\t\t\t\t\t{\n")
		file:write("\t\t\t\t\t\tTemplate=\"" .. inventoryItemData[1] .. "\",\n")
		file:write("\t\t\t\t\t\tDisplayName=\"" .. inventoryItemData[2] .. "\",\n")
		file:write("\t\t\t\t\t\tCost=\"" .. inventoryItemData[3] .. "\",\n")
		file:write("\t\t\t\t\t\tMaxStock=\"" .. inventoryItemData[5] .. "\",\n")
		file:write("\t\t\t\t\t\tStackable=\"" .. inventoryItemData[6] .. "\",\n")
		file:write("\t\t\t\t\t},\n")
	end
	file:write("\t\t\t\t},\n")
end

----------------------------------------------------------
--				WriteBuyList(file)
----------------------------------------------------------
--this formats the items the merchants buy off the players
--to the xml file
function WriteBuyList(file)
	file:write("\t\t\t\tPurchaseList =\n")
	file:write("\t\t\t\t{\n")
	for i,iventoryItem in pairs(this:GetObjVar("buy_list")) do
		local inventoryItemData = StringSplit(iventoryItem,":")
		file:write("\t\t\t\t\t{\n")
		file:write("\t\t\t\t\t\tTemplate=\"" .. inventoryItemData[1] .. "\",\n")
		file:write("\t\t\t\t\t\tDisplayName=\"" .. inventoryItemData[2] .. "\",\n")
		file:write("\t\t\t\t\t\tPrice=\"" .. inventoryItemData[3] .. "\",\n")
		file:write("\t\t\t\t\t\tStackable=\"" .. inventoryItemData[4] .. "\",\n")
		file:write("\t\t\t\t\t},\n")
	end
	file:write("\t\t\t\t},\n")
end

--======================================================================
--					        DIALOG WINDOWS
--======================================================================

----------------------------------------------------------
-- 				IntroductionWindow(user)
----------------------------------------------------------
function IntroductionWindow(user)
	local window = DynamicWindow("IntroductionWindow","",600,260,-300,-130,"NoFrame","Center")
	--merchant name bar
	window:AddImage(140,-75,"LargeTextFieldUnsliced",320,75,"Sliced")
	window:AddLabel(300,-62,"[BBBB44]"..StripColorFromString(this:GetName()),320,24,24,"center",false,false,"PermianSlabSerif_16_Dynamic")
	--title bar
	window:AddImage(140,196,"LargeTextFieldUnsliced",320,75,"Sliced")
	window:AddLabel(300,238,"[BBBB44]"..this:GetSharedObjectProperty("Title"),320,24,24,"center",false,false,"PermianSlabSerif_16_Dynamic")

	--options bar
	if (IsGod(user) and not ActLikePlayer) then
		window:AddImage(598,-25,"LargeTextFieldUnsliced",110,35,"Sliced")
		window:AddImage(578,-2,"LargeTextFieldUnsliced",150,200,"Sliced")
		window:AddLabel(624,-18,"[FF7700]Options",110,20,20,"",true,false,"PermianSlabSerif_16_Dynamic")
	end
	--merchant view backdrop design
	for x=0,3 do
		for y=0,3 do
			window:AddImage(11+x*45,7+y*45,"heal",46,46,"Sliced","200000")
		end
	end
	--top bar
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",595,35,"Sliced")
	window:AddImage(10,6,"FullBorder",185,185,"Sliced")
	--bottom bar
	window:AddImage(0,-1,"FullBorder",580,202,"Sliced")
	window:AddImage(-7, 196,"SkillsCategoryTitleFrame",595,35,"Sliced")
	--merchant portrait
	window:AddPortrait(12,8,180,180,this,"head")

	if(this:GetObjVar("CanDoRepairs")) then
		window:AddLabel(212,13,"[BBBB44]"..this:GetObjVar("DialogText"),376,100,20,"",true,false,"PermianSlabSerif_16_Dynamic")
		window:AddImage(200,6,"FullBorder",370,90,"Sliced")

		window:AddButton(200,95,"buy_button","Button",370,35,"[FF7700]Buy Items\n[FFFFAA]click here to purchase items",nil,true,"SectionButton")
		window:AddLabel(210,104,"[BBBBBB]"..this:GetObjVar("BuyText"),370,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
		window:AddButton(200,125,"sell_button","Button",370,35,"[FF7700]Sell Items\n[FFFFAA]click here to sell items",nil,true,"SectionButton")
		window:AddLabel(210,134,"[BBBBBB]"..this:GetObjVar("SellText"),370,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
		window:AddButton(200,155,"repair_button","Button",370,35,"[FF7700]Repair Items\n[FFFFAA]click here to repair an item",nil,true,"SectionButton")
		window:AddLabel(210,164,"[BBBBBB]"..this:GetObjVar("RepairText"),370,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
		
		if (IsGod(user) and not ActLikePlayer) then
			window:AddButton(586,5,"change_dialog_text_button","Button",135,25,"[FF7700]Edit Dialog Text\n[FFFFDD]edit the merchants dialog text",nil,true,"SectionButton")
			window:AddLabel(596, 10,"[BBBB44]Edit Dialog Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")			
			
			window:AddButton(586,30,"change_buy_text_button","Button",135,25,"[FF7700]Edit Buy Button Text\n[FFFFDD]edit the merchants buy button text",nil,true,"SectionButton")
			window:AddLabel(596, 35,"[BBBB44]Edit Buy Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
			
			window:AddButton(586,55,"change_sell_text_button","Button",135,25,"[FF7700]Edit Sell Button Text\n[FFFFDD]edit the merchants sell button text",nil,true,"SectionButton")
			window:AddLabel(596, 60,"[BBBB44]Edit Sell Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
			
			window:AddButton(586,80,"change_repair_text_button","Button",135,25,"[FF7700]Edit Repair Button Text\n[FFFFDD]edit the merchants repair button text",nil,true,"SectionButton")
			window:AddLabel(596, 85,"[BBBB44]Edit Repair Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")

			window:AddButton(586,105,"change_name_text_button","Button",135,25,"[FF7700]Edit Name Text\n[FFFFDD]edit the merchants name text",nil,true,"SectionButton")
			window:AddLabel(596, 110,"[BBBB44]Edit Name Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")

			window:AddButton(586,130,"change_title_text_button","Button",135,25,"[FF7700]Edit Title Text\n[FFFFDD]edit the merchants title text",nil,true,"SectionButton")
			window:AddLabel(596, 135,"[BBBB44]Edit Title Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")

			window:AddButton(586,155,"createme_button","Button",135,35,"[FF7700]Save As Xml File\n[FFFFDD]save all this data to a xml temlate",nil,true,"SectionButton")
			window:AddLabel(600,164,"[339933]Create Me!",135,30,28,"",false,false,"PermianSlabSerif_16_Dynamic")
		end
	else
		window:AddLabel(212,13,"[BBBB44]"..this:GetObjVar("DialogText"),376,120,20,"",true,false,"PermianSlabSerif_16_Dynamic")
		window:AddImage(200,6,"FullBorder",370,120,"Sliced")

		window:AddButton(200,125,"buy_button","Button",370,35,"[FF7700]Buy Items\n[FFFFAA]click here to purchase items",nil,true,"SectionButton")
		window:AddLabel(210,134,"[BBBBBB]"..this:GetObjVar("BuyText"),370,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
		window:AddButton(200,155,"sell_button","Button",370,35,"[FF7700]Sell Items\n[FFFFAA]click here to sell items",nil,true,"SectionButton")
		window:AddLabel(210,164,"[BBBBBB]"..this:GetObjVar("SellText"),370,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")

		if (IsGod(user) and not ActLikePlayer) then				
			window:AddButton(586,5,"change_dialog_text_button","Button",135,25,"[FF7700]Edit Dialog Text\n[FFFFDD]edit the merchants dialog text",nil,true,"SectionButton")
			window:AddLabel(596, 10,"[BBBB44]Edit Dialog Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")			
			
			window:AddButton(586,30,"change_buy_text_button","Button",135,25,"[FF7700]Edit Buy Button Text\n[FFFFDD]edit the merchants buy button text",nil,true,"SectionButton")
			window:AddLabel(596, 35,"[BBBB44]Edit Buy Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")
			
			window:AddButton(586,55,"change_sell_text_button","Button",135,25,"[FF7700]Edit Sell Button Text\n[FFFFDD]edit the merchants sell button text",nil,true,"SectionButton")
			window:AddLabel(596, 60,"[BBBB44]Edit Sell Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")

			window:AddButton(586,80,"change_name_text_button","Button",135,25,"[FF7700]Edit Name Text\n[FFFFDD]edit the merchants name text",nil,true,"SectionButton")
			window:AddLabel(596, 85,"[BBBB44]Edit Name Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")

			window:AddButton(586,105,"change_title_text_button","Button",135,25,"[FF7700]Edit Title Text\n[FFFFDD]edit the merchants title text",nil,true,"SectionButton")
			window:AddLabel(596, 110,"[BBBB44]Edit Title Text",135,20,20,"",false,false,"PermianSlabSerif_16_Dynamic")			

			window:AddButton(586,155,"createme_button","Button",135,35,"[FF7700]Save As Xml File\n[FFFFDD]save all this data to a xml temlate",nil,true,"SectionButton")
			window:AddLabel(600,164,"[339933]Create Me!",135,30,28,"",false,false,"PermianSlabSerif_16_Dynamic")

		end
	end

	window:AddButton(552,-33,"close_button","Button",28,28,"[FF7700]Close Window",nil,true,"SectionButton")
	window:AddLabel(560,-27,"[AA0000]X",24,24,24,"",false,false,"PermianSlabSerif_16_Dynamic")

	user:OpenDynamicWindow(window,this)
end
----------------------------------------------------------
-- 				MerchantBuyWindow(user)
----------------------------------------------------------
function MerchantBuyWindow(user)
	local mode = this:GetObjVar("mode")
	local window = nil
	local labelColor = "[FFFFBB]"

	window = DynamicWindow("MerchantBuyWindow","[BBBB44]what would you like to buy",600,520,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",595,35,"Sliced")
	window:AddImage(-7, 476,"SkillsCategoryTitleFrame",595,35,"Sliced")

	local scrollWindow = ScrollWindow(20,20,540,450,50)
	local useIcons = this:GetObjVar("use_icons")
	if(useIcons) then
		window:AddLabel(70,3,"Item Name",100,20,18,"left",false,false,"PermianSlabSerif_16_Dynamic")
	else
		window:AddLabel(25,3,"Item Name",100,20,18,"left",false,false,"PermianSlabSerif_16_Dynamic")
	end
	window:AddLabel(455,3,"Cost",100,20,18,"center",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(344,3,"Stock",100,20,18,"center",false,false,"PermianSlabSerif_16_Dynamic")
	for sellListIndex, sellListItem in pairs(this:GetObjVar("current_stock_list")) do
		local parseItem = StringSplit(sellListItem,":")
		local template = parseItem[1]
		local displayName = parseItem[2]
		local coinCost = parseItem[3]
		local currentCount = parseItem[4]
		local maxCount = parseItem[5]
		local isStackable = parseItem[6]
		local scrollElement = ScrollElement()


		coinCost = coinCost:gsub("c","")
		local finalCost = item_value_buy_price(user,this,tonumber(coinCost))
		
		if(tonumber(currentCount) > 0) then
			scrollElement:AddImage(0,0,"SectionBackground",528,50,"Sliced")
			if(useIcons) then
				scrollElement:AddImage(5,5,tostring(tostring(GetTemplateIconId(template))),40,40,"Object")
				scrollElement:AddLabel(50,15,labelColor..displayName,340,20,26,"left",false,false,"PermianSlabSerif_16_Dynamic")
			else
				scrollElement:AddLabel(10,15,labelColor..displayName,340,20,26,"left",false,false,"PermianSlabSerif_16_Dynamic")
			end
			scrollElement:AddLabel(332,15,currentCount,100,20,26,"right",false,false,"PermianSlabSerif_16_Dynamic")
			scrollElement:AddLabel(452,15,GetMoneyString(finalCost.."c"),100,20,26,"right",false,false,"PermianSlabSerif_16_Dynamic")
			if(IsGod(user) and not ActLikePlayer) then
				scrollElement:AddButton(464,4,"sellItemToPlayer:"..sellListIndex,labelColor.."Buy",50,22,"[FF7700]Buy Item\n[FFFFBB]buy this item from this merchant",nil,true,"SectionButton")
				scrollElement:AddLabel(476,9,"[BBBB44]Buy",50,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
				scrollElement:AddButton(464,24,"deleteItem:"..sellListIndex,labelColor.."",50,22,"[FF7700]Delete Item\n[FFFFBB]delte this item from this merchant",nil,true,"SectionButton")
				scrollElement:AddLabel(468,29,"[BBBB44]Delete",50,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
			else
				scrollElement:AddButton(464,4,"sellItemToPlayer:"..sellListIndex,labelColor.."Buy",50,40,"[FF7700]Buy Item\n[FFFFBB]buy this item from this merchant",nil,true,"SectionButton")
				scrollElement:AddLabel(472,15,"[BBBB44]Buy",50,24,24,"",false,false,"PermianSlabSerif_16_Dynamic")
			end
			scrollWindow:Add(scrollElement)
		end
	end
	if (IsGod(user) and not ActLikePlayer) then
		window:AddButton(480,478,"addStock",labelColor.."",95,28,"[FF7700]Add a item to the vendors inventory\n[FFFFBB]you will get a targeting cursor use\nthis to target the item you want\nto add.",nil,true,"SectionButton")
		window:AddLabel(496,487,"[BBBB44]Add Stock",100,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	end
	window:AddScrollWindow(scrollWindow)
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				MerchantSellWindow(user)
----------------------------------------------------------
--this displays the dialog for players to buy from
function MerchantSellWindow(user)
	local mode = this:GetObjVar("mode")
	local window = nil
	local labelColor = "[FFFFBB]"
	local purchaseList = {}

	window = DynamicWindow("MerchantSellWindow","[BBBB44]what would you like to sell",600,520,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",595,35,"Sliced")
	window:AddImage(-7, 476,"SkillsCategoryTitleFrame",595,35,"Sliced")
	--end
	local scrollWindow = ScrollWindow(20,20,540,450,50)
	local useIcons = this:GetObjVar("use_icons")
	if(useIcons) then
		window:AddLabel(70,3,"Item Name",100,20,18,"left",false,false,"PermianSlabSerif_16_Dynamic")
	else
		window:AddLabel(25,3,"Item Name",100,20,18,"left",false,false,"PermianSlabSerif_16_Dynamic")
	end
	window:AddLabel(450,3,"Value",100,20,18,"center",false,false,"PermianSlabSerif_16_Dynamic")

	if (IsGod(user) and not ActLikePlayer) then
		window:AddButton(480,478,"addPurchaseItem",labelColor.."Add Item This Merchant Will Buy",95,28,"[FF7700]Add a item to the merchants buy list\n[FFFFBB]you will get a targeting cursor use\nthis to target the item you want\nto add.",nil,true,"SectionButton")
		window:AddLabel(496,487,"[BBBB44]Add Stock",100,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	end
	
	if(IsGod(user) and not ActLikePlayer) then
		purchaseList = GeneratePurchasableItemsForAdmin(user)
	else
		purchaseList = GeneratePurchasableItemsFromPlayer(user)
	end

	for purchaseIndex, purchaseItem in pairs(purchaseList) do
		local parseItem = StringSplit(purchaseItem,":")
		local displayName = parseItem[1]
		local objectToBuy = parseItem[2]
		local priceToBuy = parseItem[3]
		local template = parseItem[5]
		local scrollElement = ScrollElement()

 		scrollElement:AddImage(0,0,"SectionBackground",528,50,"Sliced")
 		if(useIcons) then
 			scrollElement:AddImage(5,5,tostring(GetTemplateIconId(template)),40,40,"Object")
 			scrollElement:AddLabel(50,15,labelColor..displayName,340,20,26,"left",false,false,"PermianSlabSerif_16_Dynamic")
 		else
 			scrollElement:AddLabel(10,15,labelColor..displayName,340,20,26,"left",false,false,"PermianSlabSerif_16_Dynamic")
 		end
 		scrollElement:AddLabel(452,15,GetMoneyString(priceToBuy),100,20,26,"right",false,false,"PermianSlabSerif_16_Dynamic")
 		if(IsGod(user) and not ActLikePlayer) then
				scrollElement:AddButton(464,4,"sellItem:"..objectToBuy..":"..priceToBuy,labelColor.."Sell",50,22,"[FF7700]Sell Item\n[FFFFBB]sell this item from this merchant",nil,true,"SectionButton")
				scrollElement:AddLabel(476,9,"[BBBB44]Sell",50,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
				scrollElement:AddButton(464,24,"deleteItem:"..purchaseIndex,labelColor.."",50,22,"[FF7700]Delete Item\n[FFFFBB]delte this item from this merchant",nil,true,"SectionButton")
				scrollElement:AddLabel(468,29,"[BBBB44]Delete",50,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
 		else
 			scrollElement:AddButton(464,4,"sellItem:"..objectToBuy..":"..priceToBuy,labelColor.."Sell",50,40,"[FF7700]Sell Item\n[FFFFBB]sell this item to the vendor",nil,true,"SectionButton")
 			scrollElement:AddLabel(472,16,"[BBBB44]Sell",60,24,24,"",false,false,"PermianSlabSerif_16_Dynamic")
 		end
 		scrollWindow:Add(scrollElement)
	end
	-- end	

	window:AddScrollWindow(scrollWindow)
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
-- 				AddToBuyList(target)
----------------------------------------------------------
--this is the dialog for the admin to add an item in which
--the merchant will purchase from the player
function AddToBuyList(target)
	local window = DynamicWindow("AddToBuyListkWindow","[BBBB44]Add Item To Buy List",500,290,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 226,"SkillsCategoryTitleFrame",495,35,"Sliced")

	local stackable = "false"
	if(CheckIsObjectStackable(target)) then stackable = "true" end
	local name, color = StripColorFromString(target:GetName())
	
	if(target:HasObjVar("SingularName")) then name = target:GetObjVar("SingularName") end

	window:AddLabel(10,10,"Name",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,40,"Template",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,70,"Price",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,100,"Stackable",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	
	window:AddLabel(65,135,"[FF7700]*be sure to check your spelling and information*",460,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,10,375,20,"text_field_display_name",name)
	window:AddTextField(100,40,375,20,"text_field_template",target:GetCreationTemplateId())

	local buyprice,sellprice = GetItemValuesFor(target:GetCreationTemplateId())
	
	if(sellprice == -1) then sellprice = 10 end
	window:AddTextField(100,70,375,20,"text_field_price",tostring(sellprice))
	

	window:AddTextField(100,100,375,20,"text_field_stackable",stackable)
	--window:AddTextField(100,130,375,20,"text_field_icon","Magic Barrier")
	window:AddButton(10,160,"addBuyListItem","Add To Buy List",460,28,"[FF7700]Add To Buy List\n[FFFFBB]add this to the buy list",nil,true,"SectionButton")
	window:AddLabel(185,169,"[BBBB44]Add To Buy List",120,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddButton(10,190,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel adding this item",nil,true,"SectionButton")
	window:AddLabel(210,199,"[BBBB44]Cancel",60,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	--here is that stupid user targeting fix
	UserForTargeting:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				EditNameWindow(user)
----------------------------------------------------------
function EditNameWindow(user)
	local window = DynamicWindow("MerchantEditNameWindow","[BBBB44]Editing Merchant Name",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"New Name",90,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,8,375,20,"edit_name_field",this:GetName())
	window:AddButton(10,30,"changeName","Rename Merchant",460,28,"[FF7700]Rename Merchant\n[FFFFBB]update the merchants name",nil,true,"SectionButton")
	window:AddLabel(185,39,"[BBBB44]Rename Merchant",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,55,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel renaming the merchant",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				EditTitleWindow(user)
----------------------------------------------------------
function EditTitleWindow(user)
	local window = DynamicWindow("MerchantEditTitleWindow","[BBBB44]Editing Merchant Title",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"New Title",95,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,8,375,20,"edit_title_field",this:GetSharedObjectProperty("Title"))
	window:AddButton(10,30,"changeTitle","New Title",460,28,"[FF7700]Change Merchant Title\n[FFFFBB]update the merchants title",nil,true,"SectionButton")
	window:AddLabel(196,39,"[BBBB44]Change Title",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,55,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel renaming the merchant",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				EditBuyTextWindow(user)
----------------------------------------------------------
function EditBuyTextWindow(user)
	local window = DynamicWindow("MerchantEditBuyTextWindow","[BBBB44]Editing Buy Text",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"Buy Text",90,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,8,375,20,"edit_buy_field",this:GetObjVar("BuyText"))
	window:AddButton(10,30,"changeBuyText","",460,28,"[FF7700]Edit Buy Text\n[FFFFBB]update the merchants buy text label",nil,true,"SectionButton")
	window:AddLabel(196,39,"[BBBB44]Edit Buy Text",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,55,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel editing the merchants buy text",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				EditSellTextWindow(user)
----------------------------------------------------------
function EditSellTextWindow(user)
	local window = DynamicWindow("MerchantEditSellTextWindow","[BBBB44]Editing Sell Text",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"Sell Text",90,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,8,375,20,"edit_sell_field",this:GetObjVar("SellText"))
	window:AddButton(10,30,"changeSellText","",460,28,"[FF7700]Edit Sell Text\n[FFFFBB]update the merchants sell text label",nil,true,"SectionButton")
	window:AddLabel(194,39,"[BBBB44]Edit Sell Text",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,55,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel editing the merchants sell text",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				EditRepairTextWindow(user)
----------------------------------------------------------
function EditRepairTextWindow(user)
	local window = DynamicWindow("MerchantEditRepairTextWindow","[BBBB44]Editing Repair Text",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"Repair Text",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(110,8,365,20,"edit_repair_field",this:GetObjVar("RepairText"))
	window:AddButton(10,30,"changeRepairText","",460,28,"[FF7700]Edit Repair Text\n[FFFFBB]update the merchants repair text label",nil,true,"SectionButton")
	window:AddLabel(184,39,"[BBBB44]Edit Repair Text",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,55,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel editing the merchants repair text",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				RepairWindow(user,cost)
----------------------------------------------------------
function RepairWindow(user,cost,repairItemId)
	local window = DynamicWindow("MerchantRepairWindow","[BBBB44]I can repair this",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"Repair Cost for this item is " .. GetMoneyString(tostring(cost)),400,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")

	window:AddButton(10,30,"repairItem:"..tostring(cost) .. ":" .. repairItemId,"",460,28,"[FF7700]Repair Item\n[FFFFBB] by accepting you will pay "..GetMoneyString(tostring(cost)).."[FFFFBB] to repair this item",nil,true,"SectionButton")
	window:AddLabel(200,39,"[BBBB44]Repair Item",152,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,55,"cancel:","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel editing the merchants repair text",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				EditDialogTextWindow(user)
----------------------------------------------------------
function EditDialogTextWindow(user,should_clear)
	local window = DynamicWindow("MerchantEditDialogTextWindow","[BBBB44]Editing Dialog Text",500,220,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 186,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(13,10,"Dialog Text",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	if not(should_clear) then
		window:AddTextField(110,8,365,120,"edit_dialog_field",this:GetObjVar("DialogText"))
	else
		window:AddTextField(110,8,365,120,"edit_dialog_field","")
	end
	window:AddButton(10,30,"clearDialogText","",90,28,"[FF7700]Clear Dialog Text\n[FFFFBB]clears the dialog text field",nil,true,"SectionButton")
	window:AddLabel(39,37,"[BBBB44]Clear",90,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	
	window:AddButton(10,130,"changeDialogText","",460,28,"[FF7700]Edit Dialog Text\n[FFFFBB]update the merchants dialog text label",nil,true,"SectionButton")
	window:AddLabel(184,139,"[BBBB44]Edit Dialog Text",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")	
	window:AddButton(10,155,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel editing the merchants dialog text",nil,true,"SectionButton")
	window:AddLabel(215,164,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--				AddStockWindow(target)
----------------------------------------------------------
--this is the dialog in which the admin can use to add a 
--item he wants the merchant to sell
function AddStockWindow(target)

	local window = DynamicWindow("AddToStockWindow","[BBBB44]Add Item To Stock",500,320,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 256,"SkillsCategoryTitleFrame",495,35,"Sliced")

	--local window = DynamicWindow("AddToStockWindow","[FFFFBB]Add Item To Stock",500,320,-300,-380,"Default","Center")
	local stackable = "false"
	if(CheckIsObjectStackable(target)) then stackable = "true" end
	local name, color = StripColorFromString(target:GetName())

	if(target:HasObjVar("SingularName")) then name = target:GetObjVar("SingularName") end

	local buyprice,sellprice = GetItemValuesFor(target:GetCreationTemplateId())
	
	if(buyprice == -1) then buyprice = 100 end
	--window:AddTextField(100,70,375,20,"text_field_price",tostring(buyprice))

	window:AddLabel(10,10,"Name",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,40,"Template",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,70,"Cost",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,100,"Max Stock",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(10,130,"Stackable",100,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddLabel(65,165,"[FF7700]*be sure to check your spelling and information*",460,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")

	window:AddTextField(100,10,375,20,"text_field_display_name",name)
	window:AddTextField(100,40,375,20,"text_field_template",target:GetCreationTemplateId())
	window:AddTextField(100,70,375,20,"text_field_cost",tostring(buyprice))
	window:AddTextField(100,100,375,20,"text_field_max_stock","10")
	window:AddTextField(100,130,375,20,"text_field_stackable",stackable)
	--window:AddTextField(100,160,375,20,"text_field_icon","Magic Barrier")

	window:AddButton(10,190,"addStockItem","Add to Stock",460,28,"[FF7700]Add Item To Stock\n[FFFFDD]add this item to inventory",nil,true,"SectionButton")
	window:AddLabel(194,199,"[BBBB44]Add To Stock",120,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddButton(10,220,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFBB]cancel adding item to inventory",nil,true,"SectionButton")
	window:AddLabel(210,229,"[BBBB44]Cancel",60,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	--here is that stupid user targeting fix
	UserForTargeting:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--			BuyQuantityWindow(user,index)
----------------------------------------------------------
--when a player is buying a item with quantity, they may
--select the amount. it auto fills to the max left in stock
function BuyQuantityWindow(user,index)
	local current_stock_list = this:GetObjVar("current_stock_list")
	local parseItem = StringSplit(current_stock_list[tonumber(index)],":")
	local displayName = parseItem[2]
	local coinCost = parseItem[3]
	local currentCount = parseItem[4]

	local window = DynamicWindow("MerchantBuyQuantityWindow","[BBBB44]How many will you buy?",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(10,10,"Amount",80,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,10,375,20,"quantity_to_buy",currentCount)
	window:AddButton(10,30,"buyQuantity:"..index,"Purchase Quantity",460,28,"[FF7700]Purchase Quanitity\n[FFFFDD]purchase the quantity of items",nil,true,"SectionButton")
	window:AddLabel(209,39,"[BBBB44]Purchase",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddButton(10,55,"cancel","Cancel",460,28,"[FF7700]Cancel\n[FFFFDD]cancel purchase",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")
	user:OpenDynamicWindow(window,this)
end

----------------------------------------------------------
--			SellQuantityWindow(user,data)
----------------------------------------------------------
--this is when the player wants to sell a quantity of items
--to the merchant. it auto fills to the max stack for the 
--player.
function SellQuantityWindow(user,data)
	local parseItem = StringSplit(data,":")
	local obj = parseItem[2]
	local object = GameObj(tonumber(obj))
	local stackCount = tostring(GetObjectStackCount(object)) or "0"

	local window = DynamicWindow("MerchantSellQuantityWindow","[BBBB44]How many will you sell?",500,120,-300,-300,"NoFrame","Center")
	window:AddImage(-7,-35,"SkillsCategoryTitleFrame",495,35,"Sliced")
	window:AddImage(-7, 86,"SkillsCategoryTitleFrame",495,35,"Sliced")

	window:AddLabel(10,10,"Amount",80,20,20,"left",false,false,"PermianSlabSerif_16_Dynamic")
	window:AddTextField(100,10,375,20,"quantity_to_sell",stackCount)

	window:AddButton(10,30,"sellQuantity:"..data,"Sell Quantity",465,28,"[FF7700]Sell Quantity\n[FFFFDD]sell the quanitity of items",nil,true,"SectionButton")
	window:AddLabel(222,39,"[BBBB44]Sell",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")

	window:AddButton(10,55,"cancel","Cancel",465,28,"[FF7700]Cancel\n[FFFFDD]cancel selling",nil,true,"SectionButton")
	window:AddLabel(215,64,"[BBBB44]Cancel",140,18,18,"",false,false,"PermianSlabSerif_16_Dynamic")

	user:OpenDynamicWindow(window,this)
end

